
#if !defined(EC_DOPPLEGANGER_H)
#define EC_DOPPLEGANGER_H


extern pthread_t Doppleganger_Run(char *iface, char *IP1, char *IP2, char *MAC1, char *MAC2);

#endif

/* EOF */
